import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = window.innerWidth;
const height = window.innerHeight;
const centerX = width / 2;
const centerY = height / 2;

const faceStrokeWidth = 19;
const faceColor = "#FABC00";

// Eyes
const eyeOffsetX = 90;
const eyeOffsetY = -30;
const eyeRadius = 50;
const eyeStrokeWidth = 5;

const irisRadius = eyeRadius * 0.7;
const irisOffsetX = (-irisRadius / 2) + 10;
const irisOffsetY = (irisRadius / 2) - 7;
const irisColor = "#88C9";

const pupilRadius = eyeRadius * 0.2;
const pupilOffsetX = irisOffsetX - (irisRadius / 4);
const pupilOffsetY = irisOffsetY + (irisRadius / 4);

// Eyebrows
const eyebrowOffsetX = -eyeRadius - 10;
const eyebrowOffsetY = -60;
const eyebrowWidth = 130;
const eyebrowHeight = 20;
const eyebrowRotation = 10;

// Hair
// hairPoints start from top left, moving counter-clockwise
//https://www.google.com/url?sa=i&url=https%3A%2F%2Fdannyphantom.fandom.com%2Fwiki%2FDanny_Phantom_(character)&psig=AOvVaw3e8HXuMa2sRLYIV0zBsMQw&ust=1599091918088000&source=images&cd=vfe&ved=0CAIQjRxqFwoTCNi8hOCXyesCFQAAAAAdAAAAABAI
const hairPoints = -centerX*0.6 + "," + -centerY*0.9 + " " +
                   -centerX*0.5 + "," + -centerY*0.1 + " " +
                   -centerX*0.4 + "," + -centerY*0.5 + " " +
                   0 + "," + -centerY*0.4 + " " +
      						 -centerX*0.05 + "," + -centerY*0.6 + " " +
      				   	 centerX*0.6 + "," + -centerY*0.1 + " " +
      				   	 centerX*0.5 + "," + -centerY*0.8 + " " +
      				   	 centerX*0.6 + "," + -centerY*0.7 + " " +
      						 centerX*0.5 + "," + -centerY + " " +
      				   	 0 + "," + -centerY*1.1 + " " +
      						 centerX*0.05 + "," + -centerY*1.3 + " ";
const hairColor = "#ACBC90";
const hairStrokeColor = "#3E4F5B";
const hairStrokeWidth = 8;

// Nose
const nosePoints = 0 + "," + -centerY*0.2 + " " +
                   centerX*0.01 + "," + centerY*0.1 + " " +
      						 centerX*0.05 + "," + centerY*0.1 + " " +
      						 centerX*0.02 + "," + centerY*0.2 + " ";
const noseStrokeWidth = 8;

// Mouth
const mouthWidth = 10;
const mouthRadius = 90;

const mouthArc = arc()
	.innerRadius(mouthRadius)
	.outerRadius(mouthRadius + mouthWidth)
	.startAngle(Math.PI * 0.8)
	.endAngle(Math.PI * 1.4);



const App = () => (
  <svg width={width} height={height}>
    <g transform={`translate(${centerX},${centerY})`}>
      // Face
      <circle
        r={centerY - faceStrokeWidth / 2}
        fill={faceColor}
        stroke="black"
        stroke-width={faceStrokeWidth}
      />
      
      // Left Eye
      <circle
        cx={-eyeOffsetX}
        cy={eyeOffsetY}
        r={eyeRadius}
        fill="white"
        stroke="black"
        stroke-width={eyeStrokeWidth}
      />
      // Left Iris
      <circle
        cx={-eyeOffsetX + irisOffsetX}
        cy={eyeOffsetY+ irisOffsetY}
        r={irisRadius}
        fill={irisColor}
      />
      // Left Pupil
      <circle
        cx={-eyeOffsetX+pupilOffsetX}
        cy={eyeOffsetY+pupilOffsetY}
        r={pupilRadius}
        fill="black"
      />
      // Right Eye
      <circle
        cx={eyeOffsetX}
        cy={eyeOffsetY}
        r={eyeRadius}
        fill="white"
        stroke="black"
        stroke-width={eyeStrokeWidth}
      />
      // Right Iris
      <circle
        cx={eyeOffsetX+irisOffsetX}
        cy={eyeOffsetY+irisOffsetY}
        r={irisRadius}
        fill={irisColor}
      />
      // Right Pupil
      <circle
        cx={eyeOffsetX+pupilOffsetX}
        cy={eyeOffsetY+pupilOffsetY}
        r={pupilRadius}
        fill="black"
      />
      
      
      // Left Eyebrow
      <rect
        width={eyebrowWidth}
        height={eyebrowHeight}
        x={-eyeOffsetX + eyebrowOffsetX}
        y={eyeOffsetY + eyebrowOffsetY}
        transform={`rotate(${eyebrowRotation})`}
      />
      // Right Eyebrow
      <rect
        width={eyebrowWidth}
        height={eyebrowHeight}
        x={eyeOffsetX + eyebrowOffsetX}
        y={eyeOffsetY + eyebrowOffsetY}
        transform={`rotate(${-eyebrowRotation})`}
      />
      
      // Mouth
      <path
        d={mouthArc()}
        transform={`translate(${-30},${60})`}
      />
      
      // Nose
      <polyline
        points={nosePoints}
        fill = "none"
        stroke = "brown"
        stroke-width = {noseStrokeWidth}
      />
      
      // Hair
      <polygon
        points={hairPoints}
        fill = {hairColor}
        opacity="1" //used for debugging
        stroke={hairStrokeColor}
        stroke-width={hairStrokeWidth}
      />
    </g>
  </svg>
);

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);